pub struct AnyRef<'a> { /* private fields */ }Expand description
ASN.1 ANY: represents any explicitly tagged ASN.1 value.
This is a zero-copy reference type which borrows from the input data.
Technically ANY hasn’t been a recommended part of ASN.1 since the X.209
revision from 1988. It was deprecated and replaced by Information Object
Classes in X.680 in 1994, and X.690 no longer refers to it whatsoever.
Nevertheless, this crate defines an ANY type as it remains a familiar
and useful concept which is still extensively used in things like
PKI-related RFCs.
Implementations
Sourceimpl<'a> AnyRef<'a>
impl<'a> AnyRef<'a>
Sourcepub const fn new(tag: Tag, bytes: &'a [u8]) -> Result<Self, Error>
pub const fn new(tag: Tag, bytes: &'a [u8]) -> Result<Self, Error>
Create a new AnyRef from the provided Tag and DER bytes.
Errors
Returns Error with ErrorKind::Length if bytes is too long.
Sourcepub fn decode_as<T>(self) -> Result<T, <T as DecodeValue<'a>>::Error>where
T: Choice<'a> + DecodeValue<'a>,
pub fn decode_as<T>(self) -> Result<T, <T as DecodeValue<'a>>::Error>where
T: Choice<'a> + DecodeValue<'a>,
Sourcepub fn decode_as_encoding<T>(
self,
encoding: EncodingRules,
) -> Result<T, <T as DecodeValue<'a>>::Error>where
T: Choice<'a> + DecodeValue<'a>,
pub fn decode_as_encoding<T>(
self,
encoding: EncodingRules,
) -> Result<T, <T as DecodeValue<'a>>::Error>where
T: Choice<'a> + DecodeValue<'a>,