pub struct GeneralizedTime(/* private fields */);Expand description
ASN.1 GeneralizedTime type.
This type implements the validity requirements specified in RFC 5280 Section 4.1.2.5.2, namely:
For the purposes of this profile, GeneralizedTime values MUST be expressed in Greenwich Mean Time (Zulu) and MUST include seconds (i.e., times are
YYYYMMDDHHMMSSZ), even where the number of seconds is zero. GeneralizedTime values MUST NOT include fractional seconds.
Implementations
Sourceimpl GeneralizedTime
impl GeneralizedTime
Sourcepub const fn from_date_time(datetime: DateTime) -> Self
pub const fn from_date_time(datetime: DateTime) -> Self
Create a GeneralizedTime from a DateTime.
Sourcepub const fn to_date_time(&self) -> DateTime
pub const fn to_date_time(&self) -> DateTime
Convert this GeneralizedTime into a DateTime.
Sourcepub fn from_unix_duration(unix_duration: Duration) -> Result<Self>
pub fn from_unix_duration(unix_duration: Duration) -> Result<Self>
Create a new GeneralizedTime given a Duration since UNIX_EPOCH
(a.k.a. “Unix time”).
Errors
Returns Error with a value error kind in the event unix_duration could not be parsed.
Sourcepub fn to_unix_duration(&self) -> Duration
pub fn to_unix_duration(&self) -> Duration
Get the duration of this timestamp since UNIX_EPOCH.
Sourcepub fn from_system_time(time: SystemTime) -> Result<Self>
pub fn from_system_time(time: SystemTime) -> Result<Self>
Sourcepub fn to_system_time(&self) -> SystemTime
pub fn to_system_time(&self) -> SystemTime
Convert to SystemTime.