Int

Struct Int 

pub struct Int { /* private fields */ }
Available on crate feature alloc only.
Signed arbitrary precision ASN.1 INTEGER type.

Provides heap-allocated storage for big endian bytes which comprise an signed integer value.

Intended for use cases like very large integers that are used in cryptographic applications (e.g. keys, signatures).

Implementations

Source

impl Int

pub fn new(bytes: &[u8]) -> Result<Self>

Create a new Int from a byte slice.

Errors

If bytes is too long.

pub fn as_bytes(&self) -> &[u8]

Borrow the inner byte slice which contains the least significant bytes of a big endian integer value with all leading ones stripped.

pub fn len(&self) -> Length

Get the length of this Int in bytes.

pub fn is_empty(&self) -> bool

Is the inner byte slice empty?