IntRef

Struct IntRef 

pub struct IntRef<'a> { /* private fields */ }
Signed arbitrary precision ASN.1 INTEGER reference type.

Provides direct access to the underlying big endian bytes which comprise an signed integer value.

Intended for use cases like very large integers that are used in cryptographic applications (e.g. keys, signatures).

Implementations

Source

impl<'a> IntRef<'a>

pub fn new(bytes: &'a [u8]) -> Result<Self>

Create a new IntRef from a byte slice.

Errors

Returns Error if bytes is too long.

pub fn as_bytes(&self) -> &'a [u8]

Borrow the inner byte slice which contains the least significant bytes of a big endian integer value with all leading ones stripped.

pub fn len(&self) -> Length

Get the length of this IntRef in bytes.

pub fn is_empty(&self) -> bool

Is the inner byte slice empty?