SetOfRef

Struct SetOfRef 

pub struct SetOfRef<'a, T>
where T: DerOrd,
{ /* private fields */ }
ASN.1 SET OF with a reference to an array.

This type implements a viewer in a SET OF type and does not depend on alloc support.

Implementations

Source

impl<'a, T> SetOfRef<'a, T>
where T: Decode<'a> + 'a + Clone + DerOrd,

pub fn get(&self, index: usize) -> Option<T>
where T: Decode<'a> + 'a + Clone,

Get the nth element from this SetOfRef.

pub fn iter(&self) -> SetOfRefIter<'a, T>
where T: Decode<'a> + 'a,

Iterate over the elements of this SetOfRef.

Panics

Panics if the inner byte slice contains invalid data that cannot be parsed by SliceReader.

pub fn is_empty(&self) -> bool

Is this SetOfRef empty?

pub fn len(&self) -> usize
where T: Decode<'a> + 'a + Clone,

Number of elements in this SetOfRef.