SetOfVec

Struct SetOfVec 

pub struct SetOfVec<T>
where T: DerOrd,
{ /* private fields */ }
Available on crate feature alloc only.
ASN.1 SET OF backed by a Vec.

This type implements an append-only SET OF type which is heap-backed and depends on alloc support.

Implementations

Source

impl<T> SetOfVec<T>
where T: DerOrd,

pub fn new() -> Self

Available on crate features alloc or heapless only.

Create a new SetOfVec.

pub fn from_iter<I>(iter: I) -> Result<Self, Error>
where I: IntoIterator<Item = T>,

Available on crate features alloc or heapless only.

Create a new SetOfVec from the given iterator.

Note: this is an inherent method instead of an impl of the FromIterator trait in order to be fallible.

Errors

If a sorting error occurred.

pub fn extend<I>(&mut self, iter: I) -> Result<(), Error>
where I: IntoIterator<Item = T>,

Available on crate features alloc or heapless only.

Extend a SetOfVec using an iterator.

Note: this is an inherent method instead of an impl of the Extend trait in order to be fallible.

Errors

If a sorting error occurred.

pub fn insert(&mut self, item: T) -> Result<(), Error>

Available on crate features alloc or heapless only.

Insert an item into this SetOfVec. Must be unique.

Errors

If item is a duplicate or a sorting error occurred.

pub fn insert_ordered(&mut self, item: T) -> Result<(), Error>

Available on crate features alloc or heapless only.

Insert an item into this SetOfVec. Must be unique.

Items MUST be added in lexicographical order according to the DerOrd impl on T.

Errors

If a sorting error occurred.

pub fn as_slice(&self) -> &[T]

Available on crate features alloc or heapless only.

Borrow the elements of this SetOfVec as a slice.

pub fn get(&self, index: usize) -> Option<&T>

Available on crate features alloc or heapless only.

Get the nth element from this SetOfVec.

pub fn into_vec(self) -> Vec<T>

Available on crate features alloc or heapless only.

Convert this SetOfVec into the inner Vec.

pub fn iter(&self) -> SetOfIter<'_, T>

Available on crate features alloc or heapless only.

Iterate over the elements of this SetOfVec.

pub fn is_empty(&self) -> bool

Available on crate features alloc or heapless only.

Is this SetOfVec empty?

pub fn len(&self) -> usize

Available on crate features alloc or heapless only.

Number of elements in this SetOfVec.