pub struct Uint { /* private fields */ }Expand description
Unsigned arbitrary precision ASN.1 INTEGER type.
Provides heap-allocated storage for big endian bytes which comprise an unsigned integer value.
Intended for use cases like very large integers that are used in cryptographic applications (e.g. keys, signatures).
Implementations