pub struct UtcTime(/* private fields */);Expand description
ASN.1 UTCTime type.
This type implements the validity requirements specified in RFC 5280 Section 4.1.2.5.1, namely:
For the purposes of this profile, UTCTime values MUST be expressed in Greenwich Mean Time (Zulu) and MUST include seconds (i.e., times are
YYMMDDHHMMSSZ), even where the number of seconds is zero. Conforming systems MUST interpret the year field (YY) as follows:
- Where
YYis greater than or equal to 50, the year SHALL be interpreted as19YY; and- Where
YYis less than 50, the year SHALL be interpreted as20YY.
Note: Due to common operations working on UNIX_EPOCH UtcTimes are
only supported for the years 1970-2049.
Implementations
Sourceimpl UtcTime
impl UtcTime
Sourcepub fn from_date_time(datetime: DateTime) -> Result<Self>
pub fn from_date_time(datetime: DateTime) -> Result<Self>
Create a UtcTime from a DateTime.
Errors
Returns Error in the event datetime has a year that exceeds UtcTime::MAX_YEAR.
Sourcepub fn to_date_time(&self) -> DateTime
pub fn to_date_time(&self) -> DateTime
Sourcepub fn from_unix_duration(unix_duration: Duration) -> Result<Self>
pub fn from_unix_duration(unix_duration: Duration) -> Result<Self>
Sourcepub fn to_unix_duration(&self) -> Duration
pub fn to_unix_duration(&self) -> Duration
Get the duration of this timestamp since UNIX_EPOCH.
Sourcepub fn from_system_time(time: SystemTime) -> Result<Self>
pub fn from_system_time(time: SystemTime) -> Result<Self>
Sourcepub fn to_system_time(&self) -> SystemTime
pub fn to_system_time(&self) -> SystemTime
Convert to SystemTime.