Header

Struct Header 

pub struct Header { /* private fields */ }
ASN.1 DER headers: tag + length component of TLV-encoded values

Examples

use der::{Decode, Header, Length, Reader, SliceReader, Tag};

let mut reader = SliceReader::new(&[0x04, 0x02, 0x31, 0x32]).unwrap();
let header = Header::decode(&mut reader).expect("valid header");

assert_eq!(header, Header::new(Tag::OctetString, Length::new(2)));

assert_eq!(reader.read_slice(2u8.into()).unwrap(), b"12");
use der::{Encode, Header, Length, Tag};
let header = Header::new(Tag::Sequence, Length::new(256));

// Header of 256-byte SEQUENCE is 4-byte long
assert_eq!(header.encoded_len(), Ok(Length::new(4)));

Implementations

Source

impl Header

pub fn new(tag: Tag, length: Length) -> Self

Create a new Header from a Tag and a Length.

pub fn tag(&self) -> Tag

Tag of this header.

pub fn length(&self) -> Length

Length of this header.

pub fn is_constructed(&self) -> bool

True if the Tag of this header has its constructed bit set.

pub fn with_length(&self, length: Length) -> Self

Copy of header with adjusted length.

pub fn peek<'a>(reader: &impl Reader<'a>) -> Result<Self>

Peek forward in the reader, attempting to decode a Header at the current position.

Does not modify the reader’s state.

Errors

Returns Error in the event a header decoding error occurred.