pub struct Int { /* private fields */ }Available on crate feature
alloc only.Expand description
Signed arbitrary precision ASN.1 INTEGER type.
Provides heap-allocated storage for big endian bytes which comprise an signed integer value.
Intended for use cases like very large integers that are used in cryptographic applications (e.g. keys, signatures).
Implementations