pub struct SequenceRef { /* private fields */ }Expand description
The SequenceRef type provides raw access to the octets which comprise a
DER-encoded SEQUENCE.
This is a zero-copy reference type which borrows from the input data.
Implementations