pub trait OwnedToRef {
type Borrowed<'a>
where Self: 'a;
// Required method
fn owned_to_ref(&self) -> Self::Borrowed<'_>;
}Expand description
A trait for borrowing data from an owned struct
This converts an object owning the data to one that will borrowing the content. The newly created object lifetime will be tied to the object owning the data.
This is similar to alloc::borrow::Borrow or core::convert::AsRef but this returns
an owned structure that references directly the backing slices instead of borrowing
the whole structure.
Required Associated Types
Required Methods
Sourcefn owned_to_ref(&self) -> Self::Borrowed<'_>
fn owned_to_ref(&self) -> Self::Borrowed<'_>
Creates a new object referencing back to the self for storage
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl OwnedToRef for Box<[u8]>
Available on crate feature alloc only.
impl OwnedToRef for Box<[u8]>
Available on crate feature
alloc only.Sourceimpl<T> OwnedToRef for Option<T>where
T: OwnedToRef,
impl<T> OwnedToRef for Option<T>where
T: OwnedToRef,
type Borrowed<'a> = Option<<T as OwnedToRef>::Borrowed<'a>> where T: 'a
fn owned_to_ref(&self) -> Self::Borrowed<'_>
Implementors
Sourceimpl OwnedToRef for Any
Available on crate feature alloc only.
impl OwnedToRef for Any
Available on crate feature
alloc only.Sourceimpl OwnedToRef for BitString
Available on crate feature alloc only.
impl OwnedToRef for BitString
Available on crate feature
alloc only.type Borrowed<'a> = BitStringRef<'a>
Sourceimpl OwnedToRef for Ia5String
Available on crate feature alloc only.
impl OwnedToRef for Ia5String
Available on crate feature
alloc only.type Borrowed<'a> = Ia5StringRef<'a>
Sourceimpl OwnedToRef for Int
Available on crate feature alloc only.
impl OwnedToRef for Int
Available on crate feature
alloc only.Sourceimpl OwnedToRef for PrintableString
Available on crate feature alloc only.
impl OwnedToRef for PrintableString
Available on crate feature
alloc only.type Borrowed<'a> = PrintableStringRef<'a>
Sourceimpl OwnedToRef for TeletexString
Available on crate feature alloc only.
impl OwnedToRef for TeletexString
Available on crate feature
alloc only.